Description: ErMagicBuilder help window
Keywords: ErMagicBuilderHelp

### Earth-Ref Magic Headers Help Window

The ErMagicBuilder is a Python tool for adding Earth-Ref data to MagIC project.
The top row in the dialog window shows the headers of the Earth-Ref tables. The required headers are added and cannot be removed. The bottom row in the dialog window shows a list of optional headers.
(Details on MagIC model different headers are in: `"http://earthref.org/MagIC/metadata/`)
To add or remove headers from your project model: choose the header name and click the add/remove buttons.

After you choose the headers of the tables press the OK button. You will then be guided through a series of windows to check your data and fill in the blanks.